==> person-directory-impl-1.8.4-sources.jar: org/apereo/services/persondir/support/IUsernameAttributeProvider.java <==
/**
 * Licensed to Apereo under one or more contributor license
 * agreements. See the NOTICE file distributed with this work
 * for additional information regarding copyright ownership.
 * Apereo licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file
 * except in compliance with the License.  You may obtain a
 * copy of the License at the following location:
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apereo.services.persondir.support;

import java.util.List;
import java.util.Map;

/**
 * Provider for the username attribute to use when one is not otherwise provided.
 *
 * @author Eric Dalquist

 */
public interface IUsernameAttributeProvider {
    /**
     * @return The username attribute to use when one is not otherwise provided, will never return null.
     */
    public String getUsernameAttribute();

    /**
     * @param query The query map of attributes
     * @return The username included in the query, determined using the username attribute. Returns null if no username attribute is included in the query.
     */
    public String getUsernameFromQuery(Map<String, List<Object>> query);
}

==> person-directory-impl-1.8.13-sources.jar: org/apereo/services/persondir/support/IUsernameAttributeProvider.java <==
/**
 * Licensed to Apereo under one or more contributor license
 * agreements. See the NOTICE file distributed with this work
 * for additional information regarding copyright ownership.
 * Apereo licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file
 * except in compliance with the License.  You may obtain a
 * copy of the License at the following location:
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apereo.services.persondir.support;

import java.util.List;
import java.util.Map;

/**
 * Provider for the username attribute to use when one is not otherwise provided.
 *
 * @author Eric Dalquist

 */
public interface IUsernameAttributeProvider {
    /**
     * @return The username attribute to use when one is not otherwise provided, will never return null.
     */
    String getUsernameAttribute();

    /**
     * @param query The query map of attributes
     * @return The username included in the query, determined using the username attribute. Returns null if no username attribute is included in the query.
     */
    String getUsernameFromQuery(Map<String, List<Object>> query);
}
